import React, { useState, useEffect, useRef, lazy, Suspense } from 'react';
import { Github, Linkedin, Mail, Shield, Server, Globe, Code, Menu, X, ArrowRight, MapPin, Calendar, CheckCircle, Home, User, MessageCircle, FolderOpen, Clock, Rocket, Headphones, FileText, Star, CloudLightning as Lightning } from 'lucide-react';
import ProfessionalLogo from './components/ProfessionalLogo';
import { useTranslation } from './hooks/useTranslation';

// Lazy load heavy components for better performance
const PodcastPage = lazy(() => import('./components/PodcastPage'));
const ResumePage = lazy(() => import('./components/ResumePage'));
const AboutMePage = lazy(() => import('./components/AboutMePage'));
const ServicesPage = lazy(() => import('./components/ServicesPage'));
const ContactMePage = lazy(() => import('./components/ContactMePage'));
const PhotoAlbumPage = lazy(() => import('./components/PhotoAlbumPage'));

// Loading component for suspense
const LoadingSpinner = () => (
  <div className="min-h-screen bg-gradient-to-br from-slate-50 via-blue-50 to-indigo-50 flex items-center justify-center">
    <div className="flex flex-col items-center gap-4">
      <div className="w-8 h-8 border-4 border-blue-600 border-t-transparent rounded-full animate-spin"></div>
      <p className="text-slate-600 font-medium">Loading...</p>
    </div>
  </div>
);

function App() {
  const [activeSection, setActiveSection] = useState('profile');
  const [isMobileMenuOpen, setIsMobileMenuOpen] = useState(false);
  const [showPodcast, setShowPodcast] = useState(false);
  const [showResume, setShowResume] = useState(false);
  const [showAboutMe, setShowAboutMe] = useState(false);
  const [showServices, setShowServices] = useState(false);
  const [showContact, setShowContact] = useState(false);
  const [showPhotoAlbum, setShowPhotoAlbum] = useState(false);
  const [scrollY, setScrollY] = useState(0);
  const [isLoaded, setIsLoaded] = useState(false);
  const [currentTime, setCurrentTime] = useState(new Date());
  const { t, language } = useTranslation();

  // Handle URL-based routing
  useEffect(() => {
    const path = window.location.pathname;
    if (path === '/resume') {
      setShowResume(true);
    } else if (path === '/about') {
      setShowAboutMe(true);
    } else if (path === '/services') {
      setShowServices(true);
    } else if (path === '/contact') {
      setShowContact(true);
    } else if (path === '/podcast') {
      setShowPodcast(true);
    } else if (path === '/photos') {
      setShowPhotoAlbum(true);
    }
  }, []);

  // Update URL when pages change
  useEffect(() => {
    if (showResume) {
      window.history.pushState(null, '', '/resume');
    } else if (showAboutMe) {
      window.history.pushState(null, '', '/about');
    } else if (showServices) {
      window.history.pushState(null, '', '/services');
    } else if (showContact) {
      window.history.pushState(null, '', '/contact');
    } else if (showPodcast) {
      window.history.pushState(null, '', '/podcast');
    } else if (showPhotoAlbum) {
      window.history.pushState(null, '', '/photos');
    } else {
      window.history.pushState(null, '', '/');
    }
  }, [showResume, showAboutMe, showServices, showContact, showPodcast, showPhotoAlbum]);

  const heroRef = useRef<HTMLDivElement>(null);

  // Get time-based gradient
  const getTimeBasedGradient = () => {
    const hour = new Date().getHours();
    if (hour < 6) return 'from-indigo-900 via-purple-900 to-pink-900'; // Night
    if (hour < 12) return 'from-blue-400 via-cyan-400 to-teal-400'; // Morning
    if (hour < 18) return 'from-blue-500 via-indigo-500 to-purple-500'; // Day
    return 'from-orange-400 via-red-400 to-pink-400'; // Evening
  };

  const [headerGradient, setHeaderGradient] = useState(getTimeBasedGradient());

  useEffect(() => {
    const handleScroll = () => {
      setScrollY(window.scrollY);
      
      // Update active section based on scroll
      const sections = ['profile', 'about', 'experience', 'services', 'alberta-startups'];
      const currentSection = sections.find(section => {
        const element = document.getElementById(section);
        if (element) {
          const rect = element.getBoundingClientRect();
          return rect.top <= 100 && rect.bottom >= 100;
        }
        return false;
      });
      
      if (currentSection) {
        setActiveSection(currentSection);
      }
    };

    window.addEventListener('scroll', handleScroll);
    
    // Initialize
    setIsLoaded(true);
    
    // Time update and gradient update
    const timeInterval = setInterval(() => {
      setCurrentTime(new Date());
      setHeaderGradient(getTimeBasedGradient());
    }, 60000); // Update every minute

    return () => {
      window.removeEventListener('scroll', handleScroll);
      clearInterval(timeInterval);
    };
  }, []);

  const handleSectionChange = (section: string) => {
    // Always scroll to top when navigating
    window.scrollTo(0, 0);
    
    if (section === 'about') {
      setShowAboutMe(true);
      return;
    }
    
    if (section === 'services') {
      setShowServices(true);
      return;
    }
    
    if (section === 'contact') {
      setShowContact(true);
      return;
    }
    
    if (section === 'podcast') {
      setShowPodcast(true);
      return;
    }
    
    if (section === 'resume') {
      setShowResume(true);
      return;
    }

    if (section === 'photos') {
      setShowPhotoAlbum(true);
      return;
    }

    if (section === 'aboutme') {
      setShowAboutMe(true);
      return;
    }
    
    setActiveSection(section);
    setIsMobileMenuOpen(false);
    
    const element = document.getElementById(section);
    if (element) {
      element.scrollIntoView({ behavior: 'smooth' });
    }
  };

  // Navigation items
  const navigationItems = [
    { id: 'profile', label: 'Home', icon: Home },
    { id: 'about', label: t.about, icon: User },
    { id: 'services', label: t.services, icon: Server },
    { id: 'contact', label: 'Contact Me', icon: MessageCircle }
  ];

  // Show Podcast page
  if (showPodcast) {
    return (
      <Suspense fallback={<LoadingSpinner />}>
        <PodcastPage onBack={() => { window.scrollTo(0, 0); setShowPodcast(false); }} language={language} />
      </Suspense>
    );
  }

  // Show Resume page
  if (showResume) {
    return (
      <Suspense fallback={<LoadingSpinner />}>
        <ResumePage onBack={() => { window.scrollTo(0, 0); setShowResume(false); }} language={language} />
      </Suspense>
    );
  }

  // Show About Me page
  if (showAboutMe) {
    return (
      <Suspense fallback={<LoadingSpinner />}>
        <AboutMePage onBack={() => { window.scrollTo(0, 0); setShowAboutMe(false); }} onShowResume={() => { window.scrollTo(0, 0); setShowAboutMe(false); setShowResume(true); }} language={language} />
      </Suspense>
    );
  }

  // Show Services page
  if (showServices) {
    return (
      <Suspense fallback={<LoadingSpinner />}>
        <ServicesPage onBack={() => { window.scrollTo(0, 0); setShowServices(false); }} language={language} />
      </Suspense>
    );
  }

  // Show Contact page
  if (showContact) {
    return (
      <Suspense fallback={<LoadingSpinner />}>
        <ContactMePage onBack={() => { window.scrollTo(0, 0); setShowContact(false); }} language={language} />
      </Suspense>
    );
  }

  // Show Photo Album page
  if (showPhotoAlbum) {
    return (
      <Suspense fallback={<LoadingSpinner />}>
        <PhotoAlbumPage onBack={() => { window.scrollTo(0, 0); setShowPhotoAlbum(false); }} language={language} />
      </Suspense>
    );
  }

  return (
    <div className="min-h-screen bg-gradient-to-br from-slate-50 via-blue-50 to-indigo-50">
      {/* Enhanced Header with Larger Menu */}
      <header className={`fixed top-0 left-0 right-0 z-50 transition-all duration-500 ${
        scrollY > 50 
          ? 'bg-slate-800 shadow-xl border-b border-slate-700/60' 
          : 'bg-slate-800 border-b border-slate-700/40'
      }`}>
        <div className="relative max-w-6xl mx-auto px-6 py-3">
          <div className="flex items-center justify-between">
            {/* Professional Logo */}
            <div className="flex items-center gap-3">
              <ProfessionalLogo size="md" variant="default" className="transition-all duration-300 hover:scale-105" />
            </div>

            {/* Enhanced Navigation with Larger Size */}
            <nav className="hidden lg:flex items-center gap-2 flex-1 justify-center">
              {navigationItems.map((item) => {
                const IconComponent = item.icon;
                return (
                  <button
                    key={item.id}
                    onClick={() => handleSectionChange(item.id)}
                    className={`group relative px-5 py-3 rounded-xl transition-all duration-200 ${
                      activeSection === item.id
                        ? 'bg-gradient-to-r from-blue-400/20 to-indigo-400/20 text-white shadow-md border border-blue-400/30'
                        : 'text-white hover:bg-white/10 hover:shadow-sm'
                    }`}
                  >
                    <div className="flex flex-col items-center gap-1">
                      <IconComponent className="w-5 h-5" />
                      <span className="text-sm font-medium">{item.label}</span>
                    </div>
                    {/* Active indicator */}
                    {activeSection === item.id && (
                      <div className="absolute bottom-1 left-1/2 transform -translate-x-1/2 w-1.5 h-1.5 bg-gradient-to-r from-blue-400 to-indigo-400 rounded-full" />
                    )}
                  </button>
                );
              })}
            </nav>

            {/* Right Actions */}
            <div className="flex items-center gap-3">
              {/* Email Icon */}
              <a
                href="mailto:Maisen@mamrein.com"
                className="p-2.5 text-white hover:bg-white/10 transition-colors rounded-lg hover:shadow-sm"
                title="Email Maisen"
              >
                <Mail className="w-5 h-5" />
              </a>

              {/* Photo Album Icon */}
              <button
                onClick={() => { window.scrollTo(0, 0); setShowPhotoAlbum(true); }}
                className="p-2.5 text-white hover:bg-white/10 transition-colors rounded-lg hover:shadow-sm"
                title="Photo Album"
              >
                <FolderOpen className="w-5 h-5" />
              </button>

              {/* Support Button */}
              <button
                onClick={() => { window.open('https://scunova.com/ask-sup', '_blank'); }}
                className="hidden lg:flex items-center gap-2 px-4 py-2.5 bg-white text-slate-800 rounded-lg hover:bg-slate-100 transition-all duration-200 font-medium shadow-lg hover:shadow-xl transform hover:scale-105 will-change-transform"
              >
                <Star className="w-4 h-4" />
                <span className="text-sm">Support</span>
              </button>

              {/* Mobile Menu Button */}
              <button
                className="lg:hidden p-2 text-white hover:bg-white/10 transition-colors rounded-lg"
                onClick={() => setIsMobileMenuOpen(!isMobileMenuOpen)}
              >
                {isMobileMenuOpen ? <X className="w-6 h-6" /> : <Menu className="w-6 h-6" />}
              </button>
            </div>
          </div>
        </div>
      </header>

      {/* Enhanced Mobile Navigation */}
      <div className={`
        fixed inset-0 bg-slate-800 z-40 lg:hidden transition-all duration-300
        ${isMobileMenuOpen ? 'opacity-100 visible' : 'opacity-0 invisible'}
      `}>
        <div className="pt-20 px-4 sm:px-6">
          {/* Professional Mobile Menu Header */}
          <div className="mb-6 pb-4 border-b border-slate-700/50">
            <h2 className="text-lg font-semibold text-white text-left">Navigation</h2>
            <p className="text-slate-400 text-sm text-left">Choose your destination</p>
          </div>
          
          <div className="space-y-1">
            {navigationItems.map((item, index) => {
              const IconComponent = item.icon;
              return (
                <button
                  key={item.id}
                  className={`w-full flex items-center gap-4 px-5 py-4 rounded-xl transition-all duration-200 text-left ${
                    activeSection === item.id
                      ? 'bg-gradient-to-r from-blue-500/20 to-indigo-500/20 text-white shadow-lg border border-blue-400/30'
                      : 'text-slate-300 hover:text-white hover:bg-slate-700/40 hover:shadow-md'
                  }`}
                 onClick={() => handleSectionChange(item.id)}
                >
                  {/* Icon Container - Fixed Width for Perfect Alignment */}
                  <div className="w-12 h-12 flex items-center justify-center bg-slate-700/50 rounded-lg flex-shrink-0">
                    <IconComponent className="w-5 h-5" />
                  </div>
                  {/* Content Container */}
                  <div className="flex-1 min-w-0">
                    <div className="font-medium text-base leading-tight">{item.label}</div>
                    <div className="text-xs text-slate-400 mt-0.5">
                      {item.id === 'profile' && 'Return to homepage'}
                      {item.id === 'about' && 'Learn about my journey'}
                      {item.id === 'services' && 'Professional services'}
                      {item.id === 'contact' && 'Get in touch'}
                    </div>
                  </div>
                  
                  {/* Active Indicator */}
                  {activeSection === item.id && (
                    <div className="w-2 h-2 bg-blue-400 rounded-full flex-shrink-0"></div>
                  )}
                </button>
              );
            })}
          </div>
          
          {/* Support Section */}
          <div className="mt-8 pt-6 border-t border-slate-700/50">
            <h3 className="text-sm font-medium text-slate-400 mb-3 text-left">Quick Actions</h3>
            <button
              onClick={() => { window.open('https://scunova.com/ask-sup', '_blank'); }}
              className="w-full flex items-center gap-4 px-5 py-4 bg-gradient-to-r from-green-600 to-emerald-600 text-white rounded-xl font-medium shadow-lg hover:shadow-xl transition-all duration-200 text-left"
            >
              <div className="w-12 h-12 flex items-center justify-center bg-white/20 rounded-lg flex-shrink-0">
                <Lightning className="w-5 h-5" />
              </div>
              <div className="flex-1 min-w-0">
                <div className="font-medium text-base leading-tight">Free IT Support</div>
                <div className="text-xs text-green-100 mt-0.5">Get help with tech issues</div>
              </div>
            </button>
          </div>
        </div>
      </div>

      {/* Main Content */}
      <main className="pt-20 sm:pt-24">
        {/* Profile Hero Section */}
        <section id="profile" className="relative py-4 sm:py-6 md:py-8">
          <div className="max-w-6xl mx-auto px-4 sm:px-6">
            {/* Modern Dashboard-Style Hero */}
            <div className="grid grid-cols-1 lg:grid-cols-12 gap-4 sm:gap-6">
              {/* Main Profile Card */}
              <div className="lg:col-span-8 bg-white/90 backdrop-blur-xl rounded-xl sm:rounded-2xl shadow-xl border border-white/60 p-4 sm:p-6 md:p-8 min-h-[400px] lg:min-h-[500px]">
              <div className="space-y-4 sm:space-y-6">
                {/* Top Section: Profile Image and Basic Info */}
                <div className="flex flex-col sm:flex-row gap-4 sm:gap-6 min-h-[300px] sm:min-h-[350px] md:min-h-[400px]">
                  {/* Profile Image */}
                  <div className="relative flex-shrink-0 w-full sm:w-auto h-full">
                    <div className="relative">
                      <img
                        src="/images/profle.jpg"
                        alt="Maisen Alamrein"
                        className="w-full h-auto max-h-[400px] sm:w-48 sm:h-[350px] md:w-56 md:h-[400px] rounded-xl sm:rounded-2xl border-3 sm:border-4 border-white shadow-2xl object-contain sm:object-cover ring-2 sm:ring-4 ring-blue-100/50"
                        loading="eager"
                        decoding="async"
                        fetchpriority="high"
                      />
                      
                      {/* Professional Badge */}
                      <div className="absolute -bottom-1 -right-1 sm:-bottom-2 sm:-right-2 w-8 h-8 sm:w-12 sm:h-12 bg-gradient-to-br from-green-500 to-emerald-600 rounded-full border-2 sm:border-4 border-white shadow-lg flex items-center justify-center">
                        <CheckCircle className="w-3 h-3 sm:w-5 sm:h-5 text-white" />
                      </div>
                      
                      {/* Subtle glow effect */}
                      <div className="absolute inset-0 rounded-xl sm:rounded-2xl bg-gradient-to-t from-blue-600/20 to-transparent opacity-0 hover:opacity-100 transition-opacity duration-300" />
                    </div>
                  </div>

                  {/* Basic Profile Info */}
                  <div className="flex-1 text-left h-[300px] sm:h-[350px] md:h-[400px] flex flex-col">
                    <div className="mb-3 sm:mb-4">
                      <h1 className="text-xl sm:text-2xl md:text-3xl font-bold text-slate-900 mb-1 sm:mb-2">Maisen Alamrein</h1>
                    </div>

                    {/* Quick Stats */}
                    <div className="flex-1 h-full">
                      {/* Enhanced International & Remote Experience Card */}
                      <div className="text-left p-4 sm:p-6 bg-gradient-to-br from-blue-50 via-white to-indigo-50 rounded-xl border border-blue-200/60 shadow-lg hover:shadow-xl transition-all duration-300 h-full flex flex-col">
                        {/* Header Stats */}
                        <div className="flex items-start justify-between mb-4">
                          <div>
                            <div className="text-2xl sm:text-3xl font-bold text-blue-600 mb-1">10+</div>
                            <div className="text-sm text-slate-600 font-semibold mb-1">Years</div>
                            <div className="text-sm text-slate-700 font-medium">International Experience</div>
                          </div>
                          <div className="text-right">
                            <div className="text-lg sm:text-xl font-bold text-green-600 mb-1">8+</div>
                            <div className="text-xs text-slate-600 font-semibold mb-1">Years</div>
                            <div className="text-xs text-slate-700 font-medium">Hybrid work</div>
                          </div>
                        </div>
                        
                        {/* Experience Highlights */}
                        <div className="space-y-2 mb-4">
                          <div className="flex items-center gap-2 text-sm text-slate-700">
                            <div className="w-2 h-2 bg-blue-500 rounded-full"></div>
                            <span>Global client base across 7 continents</span>
                          </div>
                          <div className="flex items-center gap-2 text-sm text-slate-700">
                            <div className="w-2 h-2 bg-green-500 rounded-full"></div>
                            <span>Hybrid work-first approach since 2017</span>
                          </div>
                          <div className="flex items-center gap-2 text-sm text-slate-700">
                            <div className="w-2 h-2 bg-purple-500 rounded-full"></div>
                            <span>Cross-cultural collaboration expertise</span>
                          </div>
                        </div>
                        
                        {/* Country Flags with Enhanced Styling */}
                        <div className="pt-3 border-t border-blue-200/60 mt-auto">
                          <div className="text-xs text-slate-600 font-medium mb-2">Countries & Regions</div>
                          <div className="flex justify-start items-center gap-3">
                            <span className="text-xl hover:scale-110 transition-transform cursor-pointer" title="Palestine">🇵🇸</span>
                            <span className="text-xl hover:scale-110 transition-transform cursor-pointer" title="Poland">🇵🇱</span>
                            <span className="text-xl hover:scale-110 transition-transform cursor-pointer" title="Canada">🇨🇦</span>
                            <span className="text-xl hover:scale-110 transition-transform cursor-pointer" title="United States">🇺🇸</span>
                            <span className="text-xl hover:scale-110 transition-transform cursor-pointer" title="United Kingdom">🇬🇧</span>
                            <span className="text-xl hover:scale-110 transition-transform cursor-pointer" title="Jordan">🇯🇴</span>
                            <span className="text-xl hover:scale-110 transition-transform cursor-pointer" title="Germany">🇩🇪</span>
                          </div>
                        </div>
                        
                      </div>
                    </div>
                  </div>
                </div>

              </div>
              </div>

              {/* Right Sidebar */}
             <div className="lg:col-span-4 space-y-4 sm:space-y-6 flex flex-col">
                {/* Social Links Card */}
                <div className="bg-white/90 backdrop-blur-xl rounded-xl sm:rounded-2xl shadow-xl border border-white/60 p-3 sm:p-4 flex flex-col flex-1 min-h-[400px] lg:min-h-[500px]">
                  <h3 className="font-semibold text-slate-900 mb-2 text-left">Connect With Me</h3>
                  
                  {/* Location and Time Info */}
                  <div className="mb-3 space-y-1 text-xs text-slate-600 flex-shrink-0">
                    <div className="flex items-center justify-between text-left">
                      <span>Calgary, AB</span>
                      <span>Mountain Time</span>
                    </div>
                    <div className="flex items-center justify-between text-left">
                      <span>{currentTime.toLocaleTimeString([], { hour: '2-digit', minute: '2-digit' })}</span>
                      <span>Local Time</span>
                    </div>
                    <div className="pt-2 mt-1 border-t border-slate-200 text-left space-y-0.5">
                      <div className="text-green-700 font-medium text-xs">Available for projects</div>
                      <div className="text-green-600 text-xs">Ready to start immediately</div>
                    </div>
                  </div>
                  
                  <div className="space-y-2 flex-1 flex flex-col justify-center">
                    <a
                      href="https://www.linkedin.com/in/maamrein/"
                      target="_blank"
                      rel="noopener noreferrer"
                      className="flex items-center gap-3 p-2.5 hover:bg-slate-50 rounded-lg transition-colors group"
                    >
                      <div className="w-8 h-8 bg-blue-600 rounded-lg flex items-center justify-center">
                        <Linkedin className="w-4 h-4 text-white" />
                      </div>
                      <div className="flex-1">
                        <div className="font-medium text-slate-900 group-hover:text-blue-600 transition-colors text-sm">LinkedIn</div>
                        <div className="text-xs text-slate-500">Professional network</div>
                      </div>
                      <ArrowRight className="w-3 h-3 text-slate-400 group-hover:text-blue-600 group-hover:translate-x-1 transition-all" />
                    </a>
                    
                    <a
                      href="https://github.com/mamreinc"
                      target="_blank"
                      rel="noopener noreferrer"
                      className="flex items-center gap-3 p-2.5 hover:bg-slate-50 rounded-lg transition-colors group"
                    >
                      <div className="w-8 h-8 bg-slate-900 rounded-lg flex items-center justify-center">
                        <Github className="w-4 h-4 text-white" />
                      </div>
                      <div className="flex-1">
                        <div className="font-medium text-slate-900 group-hover:text-slate-700 transition-colors text-sm">GitHub</div>
                        <div className="text-xs text-slate-500">Code repositories</div>
                      </div>
                      <ArrowRight className="w-3 h-3 text-slate-400 group-hover:text-slate-600 group-hover:translate-x-1 transition-all" />
                    </a>
                    
                    <a
                      href="https://soundcloud.com/techmaisen"
                      target="_blank"
                      rel="noopener noreferrer"
                      className="flex items-center gap-3 p-2.5 hover:bg-slate-50 rounded-lg transition-colors group"
                    >
                      <div className="w-8 h-8 bg-orange-600 rounded-lg flex items-center justify-center">
                        <Headphones className="w-4 h-4 text-white" />
                      </div>
                      <div className="flex-1">
                        <div className="font-medium text-slate-900 group-hover:text-orange-600 transition-colors text-sm">Podcast</div>
                        <div className="text-xs text-slate-500">Tech Evolution</div>
                      </div>
                      <ArrowRight className="w-3 h-3 text-slate-400 group-hover:text-orange-600 group-hover:translate-x-1 transition-all" />
                    </a>
                    
                    <button
                      onClick={() => { window.scrollTo(0, 0); setShowContact(true); }}
                      className="flex items-center gap-3 p-2.5 hover:bg-slate-50 rounded-lg transition-colors group w-full text-left"
                    >
                      <div className="w-8 h-8 bg-gradient-to-r from-blue-600 to-indigo-600 rounded-lg flex items-center justify-center">
                        <MessageCircle className="w-4 h-4 text-white" />
                      </div>
                      <div className="flex-1">
                        <div className="font-medium text-slate-900 group-hover:text-blue-600 transition-colors text-sm">Let's Connect</div>
                        <div className="text-xs text-slate-500">Contact information</div>
                      </div>
                      <ArrowRight className="w-3 h-3 text-slate-400 group-hover:text-blue-600 group-hover:translate-x-1 transition-all" />
                    </button>
                  </div>
                </div>

              </div>
            </div>

          </div>
        </section>


      </main>

      {/* Professional Footer */}
      <footer className="bg-slate-800 text-white">
        <div className="max-w-6xl mx-auto px-4 sm:px-6 py-8 sm:py-12">
          <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-4 gap-6 sm:gap-8">
            {/* Company Info */}
            <div className="lg:col-span-1">
              <div className="mb-4 sm:mb-6">
                <ProfessionalLogo size="sm" className="mb-2" />
              </div>
              <p className="text-slate-300 text-xs sm:text-sm leading-relaxed mb-4 sm:mb-6 text-left">
                Cybersecurity-focused IT specialist serving organizations across North America, Europe, and the Middle East with secure, scalable technology solutions.
              </p>
              <div className="flex items-center gap-3">
                <a
                  href="https://github.com/mamreinc"
                  target="_blank"
                  rel="noopener noreferrer"
                  className="w-6 h-6 sm:w-8 sm:h-8 bg-slate-700 rounded-lg flex items-center justify-center text-slate-300 hover:text-white hover:bg-slate-600 transition-colors"
                >
                  <Github className="w-3 h-3 sm:w-4 sm:h-4" />
                </a>
                <a
                  href="https://www.linkedin.com/in/maamrein/"
                  target="_blank"
                  rel="noopener noreferrer"
                  className="w-6 h-6 sm:w-8 sm:h-8 bg-slate-700 rounded-lg flex items-center justify-center text-slate-300 hover:text-white hover:bg-slate-600 transition-colors"
                >
                  <Linkedin className="w-3 h-3 sm:w-4 sm:h-4" />
                </a>
                <a
                  href="https://soundcloud.com/techmaisen"
                  target="_blank"
                  rel="noopener noreferrer"
                  className="w-6 h-6 sm:w-8 sm:h-8 bg-slate-700 rounded-lg flex items-center justify-center text-slate-300 hover:text-white hover:bg-slate-600 transition-colors"
                >
                  <Headphones className="w-3 h-3 sm:w-4 sm:h-4" />
                </a>
              </div>
            </div>

            {/* Services */}
            <div>
              <h4 className="text-base sm:text-lg font-semibold mb-4 sm:mb-6 text-left">Services</h4>
              <ul className="space-y-2 sm:space-y-3">
                <li>
                  <a
                    href="https://scunova.com/services"
                    target="_blank"
                    rel="noopener noreferrer"
                    className="text-slate-300 hover:text-white transition-colors text-xs sm:text-sm flex items-center gap-2"
                  >
                    <Shield className="w-3 h-3 sm:w-4 sm:h-4" />
                    Cybersecurity Solutions
                  </a>
                </li>
                <li>
                  <a
                    href="https://scunova.com/services"
                    target="_blank"
                    rel="noopener noreferrer"
                    className="text-slate-300 hover:text-white transition-colors text-xs sm:text-sm flex items-center gap-2"
                  >
                    <Server className="w-3 h-3 sm:w-4 sm:h-4" />
                    Cloud Infrastructure
                  </a>
                </li>
                <li>
                  <a
                    href="https://scunova.com/services"
                    target="_blank"
                    rel="noopener noreferrer"
                    className="text-slate-300 hover:text-white transition-colors text-xs sm:text-sm flex items-center gap-2"
                  >
                    <Globe className="w-3 h-3 sm:w-4 sm:h-4" />
                    Web Solutions
                  </a>
                </li>
                <li>
                  <a
                    href="https://scunova.com/services"
                    target="_blank"
                    rel="noopener noreferrer"
                    className="text-slate-300 hover:text-white transition-colors text-xs sm:text-sm flex items-center gap-2"
                  >
                    <Code className="w-3 h-3 sm:w-4 sm:h-4" />
                    IT Consulting
                  </a>
                </li>
              </ul>
            </div>

            {/* Quick Links */}
            <div>
              <h4 className="text-base sm:text-lg font-semibold mb-4 sm:mb-6 text-left">Quick Links</h4>
              <ul className="space-y-2 sm:space-y-3">
                <li>
                  <button
                    onClick={() => setShowAboutMe(true)}
                    className="text-slate-300 hover:text-white transition-colors text-xs sm:text-sm flex items-center gap-2"
                  >
                    <User className="w-3 h-3 sm:w-4 sm:h-4" />
                    About Me
                  </button>
                </li>
                <li>
                  <button
                    onClick={() => setShowResume(true)}
                    className="text-slate-300 hover:text-white transition-colors text-xs sm:text-sm flex items-center gap-2"
                  >
                    <FileText className="w-3 h-3 sm:w-4 sm:h-4" />
                    Resume
                  </button>
                </li>
                <li>
                  <button
                    onClick={() => setShowPodcast(true)}
                    className="text-slate-300 hover:text-white transition-colors text-xs sm:text-sm flex items-center gap-2"
                  >
                    <Headphones className="w-3 h-3 sm:w-4 sm:h-4" />
                    Podcast
                  </button>
                </li>
                <li>
                  <button
                    onClick={() => setShowPhotoAlbum(true)}
                    className="text-slate-300 hover:text-white transition-colors text-xs sm:text-sm flex items-center gap-2"
                  >
                    <FolderOpen className="w-3 h-3 sm:w-4 sm:h-4" />
                    Photo Album
                  </button>
                </li>
                <li>
                  <button
                    onClick={() => { window.open('https://scunova.com/ask-sup', '_blank'); }}
                    className="text-slate-300 hover:text-white transition-colors text-xs sm:text-sm flex items-center gap-2"
                  >
                    <MessageCircle className="w-3 h-3 sm:w-4 sm:h-4" />
                    Free IT Support
                  </button>
                </li>
              </ul>
            </div>

            {/* Companies */}
            <div>
              <h4 className="text-base sm:text-lg font-semibold mb-4 sm:mb-6 text-left">Companies</h4>
              <div className="space-y-3 sm:space-y-4">
                <div className="p-3 sm:p-4 bg-slate-700/50 rounded-lg border border-slate-600/50 hover:bg-slate-700 transition-colors">
                  <div className="flex items-center gap-2 sm:gap-3 mb-1 sm:mb-2">
                    <div className="w-6 h-6 sm:w-8 sm:h-8 bg-blue-600 rounded-lg flex items-center justify-center">
                      <Shield className="w-3 h-3 sm:w-4 sm:h-4 text-white" />
                    </div>
                    <div>
                      <h5 className="font-semibold text-xs sm:text-sm">
                        <a
                          href="https://scunova.com/"
                          target="_blank"
                          rel="noopener noreferrer"
                          className="hover:text-blue-300 transition-colors"
                        >
                          SecuNova Inc.
                        </a>
                      </h5>
                      <p className="text-slate-400 text-xs sm:text-sm">Cybersecurity & Web Solutions</p>
                    </div>
                  </div>
                </div>
              </div>
              <p className="text-slate-400 text-xs mt-3 sm:mt-4 italic text-left">
                Trusted by Organizations Worldwide
              </p>
            </div>
          </div>

          {/* Bottom Bar */}
          <div className="border-t border-slate-700 mt-8 sm:mt-12 pt-6 sm:pt-8">
            <div className="flex flex-col sm:flex-row sm:items-center sm:justify-between gap-3 sm:gap-4">
              <div className="flex flex-col sm:flex-row sm:items-center gap-2 sm:gap-4 text-xs sm:text-sm text-slate-400 text-left">
                <span>© 2025 Maisen Alamrein. All rights reserved.</span>
                <div className="flex items-center gap-2">
                  <div className="w-2 h-2 bg-green-500 rounded-full animate-pulse"></div>
                  <span>Available for new projects</span>
                </div>
              </div>
              <div className="flex flex-col sm:flex-row sm:items-center gap-2 sm:gap-4 text-xs sm:text-sm text-slate-400 text-left sm:text-right">
                <div className="flex items-center gap-2 sm:justify-end">
                  <MapPin className="w-3 h-3 sm:w-4 sm:h-4" />
                  <span>Calgary, AB</span>
                </div>
                <div className="flex items-center gap-2 sm:justify-end">
                  <Clock className="w-3 h-3 sm:w-4 sm:h-4" />
                  <span>{currentTime.toLocaleTimeString([], { hour: '2-digit', minute: '2-digit' })}</span>
                </div>
              </div>
            </div>
          </div>
        </div>
      </footer>
    </div>
  );
}

export default App;